package
Version:
v0.0.0-...-a4ecd53
Opens a new window with list of versions in this module.
Published: Oct 16, 2025
License: MPL-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Option[T any] func(*T)
type Ptr[T any, F any] func(*T) *F
Source Files
¶
Click to show internal directories.
Click to hide internal directories.